#
# spec file for package libregf
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libregf
%define lname	libregf1
%define timestamp	20150704
Version:        0~%timestamp
Release:        4.3
Summary:        Library to access Windows REGF-type Registry files
License:        LGPL-3.0+ and GFDL-1.3+
Group:          Productivity/File utilities
Url:            https://github.com/libyal/libregf/wiki
Source:         https://github.com/libyal/libregf/releases/download/%timestamp/%name-alpha-%timestamp.tar.gz
Source2:        Windows_NT_Registry_File_(REGF)_format.pdf
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20131003
BuildRequires:  pkgconfig(libcdata) >= 20130904
BuildRequires:  pkgconfig(libcerror) >= 20140105
BuildRequires:  pkgconfig(libcfile) >= 20130809
BuildRequires:  pkgconfig(libclocale) >= 20130609
BuildRequires:  pkgconfig(libcnotify) >= 20130609
BuildRequires:  pkgconfig(libcpath) >= 20130809
BuildRequires:  pkgconfig(libcsplit) >= 20130609
BuildRequires:  pkgconfig(libcstring) >= 20120425
BuildRequires:  pkgconfig(libcsystem) >= 20120425
BuildRequires:  pkgconfig(libfdatetime) >= 20130317
BuildRequires:  pkgconfig(libfguid) >= 20140105
BuildRequires:  pkgconfig(libuna) >= 20130728
# Using these packages (libf*) are released but are not stable per upstream
# Verified 9/19/2014
#BuildRequires:  pkgconfig(libfcache) >= 20120425
#BuildRequires:  pkgconfig(libfdata) >= 20120425
#BuildRequires:  pkgconfig(libfwnt) >= 20120426
#BuildRequires:  pkgconfig(libfwsi) >= 20120426
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libregf is a library to access Windows Registry files of the REGF
type (a non-text representation).

%package -n %lname
Summary:        Library to access Windows REGF-type Registry files
License:        LGPL-3.0+
Group:          System/Libraries

%description -n %lname
libregf is a library to access Windows Registry files of the REGF
type (a non-text representation).

%package tools
Summary:        Utilities to inspect Windows REGF-type Registry files
License:        LGPL-3.0+
Group:          Productivity/File utilities

%description tools
Several tools for inspecting Windows REGF-type Registry files.
Typically used for computer forensics.

%package devel
Summary:        Development files for libregf, a Windows REGF-type Registry file parser
License:        LGPL-3.0+ and GFDL-1.3+
Group:          Development/Libraries/C and C++
Requires:       %lname = %{version}

%description devel
libregf is a library to access Windows Registry files of the REGF
type (a non-text representation).

This subpackage contains libraries and header files for developing
applications that want to make use of %{name}.

%package -n python-%{name}
Summary:        Python bindings for libregf, a library to access Windows REGF Registry files
License:        LGPL-3.0+
Group:          Development/Libraries/Python
Requires:       %lname = %version
Requires:       python
Provides:       pyregf = %version

%description -n python-%{name}
libregf is a library to access Windows Registry files of the REGF
type (a non-text representation).

This subpackage contains the Python bindings for libregf.

%prep
%setup -qn libregf-%timestamp
cp "%{SOURCE2}" .

%build
%configure --disable-static --enable-wide-character-type --enable-python
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -name '*.la' -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%{_libdir}/libregf.so.*

%files tools
%defattr(-,root,root)
%{_bindir}/regf*
%{_mandir}/man1/regf*.1*

%files devel
%defattr(-,root,root)
%doc Windows_NT_Registry_File*.pdf
%{_includedir}/libregf.h
%{_includedir}/libregf/
%{_libdir}/libregf.so
%{_libdir}/pkgconfig/libregf.pc
%{_mandir}/man3/libregf.3*

%files -n python-%{name}
%defattr(-,root,root)
%doc AUTHORS COPYING README
%python_sitearch/pyregf.so

%changelog
* Thu Aug 13 2015 Greg.Freemyer@gmail.com
- update to 20150704
  * worked on handling corrupt hive bins
  * worked on empty hive bins data corruption scenario handling
  * worked on Python-bindings
  * Bug fixes
* Fri May  8 2015 Greg.Freemyer@gmail.com
- update to 20150315
  * bug fix in _get_sub_key_by_path for single character sub key paths
* Wed Jan 14 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
  * removed libregf_file_get_version
- update Source and URL fields to use the new github site
- use more libyal packages from OBS
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to 20140905
  * updated libfwsi version check
  * bug fix in Python-bindings
  * code clean
- update Source field to fullpath - delete DL_URL field
- use libcerror from external package
* Tue Aug 26 2014 Greg.Freemyer@gmail.com
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Requires:     %%lname = %%version
  * Provides:	pyregf = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140803
  * bug fix in Python-bindings
  * worked on Python bindings
  * worked on regfmount
  - moved values to sub directory to prevent value and key name clashes
  - added class name support
  - other tasks
  * updated dependencies
  * fix for dealing with size mismatch between value and block list size
  * improved string size corruption handling
  * worked on setup.py
  * bug fix for call to libfdata_tree_node_set_sub_nodes_data_range
  * 2014 update
  * worked on Dokan support for regfmount
* Sat Nov 23 2013 Greg.Freemyer@gmail.com
- update to v0~20131013
- clean up buildrequires
- use libyal packages from factory if feasible
* Wed Oct  2 2013 Greg.Freemyer@gmail.com
- update to v0~20130922
  * removed hardcoded codepages from value functions
  * worked on automated tests
  * updated dependencies
* Tue Aug 27 2013 Greg.Freemyer@gmail.com
- update to v0~20130821
  * fix in pyregf value data as integer function for bounds check being too strict
* Tue Jul 30 2013 Greg.Freemyer@gmail.com
- update to v0~20130716
  * updated dependencies
  * worked on tests
  * bug fix for large values
  * added support for REG_LINK as a string
  * fixed multiple open issues
  * pyregf: fix for retrieving default value by name
  * worked on tests
  * changes for strings values with trailing data
  * small update for 64-bit build
  * Textual changes
  * updates and bug fixes in pyregf
  * fixed codepage 1255 restriction
  * fixed codepage 949 and 950 restriction
  * changes for libfdata update
  * removed item flags
- changed to gz compression to simplyfy download/convert
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- organize BuildRequires to better comment why they are commented out
- ran spec-cleaner
* Wed Apr  3 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; less greedy fileslists; remove unused %%py_requires;
  do not bloat shlib package with documentation
- Enable FUSE support
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130319) for build.opensuse.org
